import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .attr('opacity', 721 / 1000)
    .style('background', '#6B6B6B');

  const dataCircles = [
    { x: 484, y: 407, r: 100, fill: '#FFFFFF' },
    { x: 484, y: 240, r: 75, fill: '#FFFFFF' },
    { x: 484, y: 121, r: 49, fill: '#FFFFFF' },
    { x: 484, y: 238, r: 15, fill: '#000000' },
    { x: 484, y: 310, r: 15, fill: '#000000' },
    { x: 484, y: 395, r: 15, fill: '#000000' },
    { x: 501, y: 115, r: 6, fill: '#2216D0' },
    { x: 469, y: 115, r: 6, fill: '#2216D0' },
  ];

  svg
    .selectAll('circle')
    .data(dataCircles)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', (d) => d.r)
    .attr('fill', (d) => d.fill)
    .attr('opacity', 970 / 1000);

  const dataRect = [
    {
      x: 457,
      y: 0,
      width: 54,
      height: 32,
      fill: '#000000',
    },
    {
      x: 432,
      y: 25,
      width: 100,
      height: 50,
      fill: '#000000',
    },
  ];
  svg
    .selectAll('rect')
    .data(dataRect)
    .join('rect')
    .attr('x', (d) => d.x)
    .attr('y', (d) => d.y)
    .attr('width', (d) => d.width)
    .attr('height', (d) => d.height)
    .attr('fill', (d) => d.fill)
    .attr('rx', '15');

  const dataLine = [
    {
      x1: 465,
      y1: 318,
      x2: 317,
      y2: 227,
      stroke: '#572700',
    },
    {
      x1: 508,
      y1: 318,
      x2: 627,
      y2: 227,
      stroke: '#572700',
    },
    //Creating stick for umbrella
    {
      x1: 300,
      y1: 100,
      x2: 330,
      y2: 450,
      stroke: 'black',
    },
  ];
  svg
    .selectAll('line')
    .data(dataLine)
    .join('line')
    .attr('x1', (d) => d.x1)
    .attr('y1', (d) => d.y1)
    .attr('x2', (d) => d.x2)
    .attr('y2', (d) => d.y2)
    .attr('stroke', (d) => d.stroke)
    .attr('stroke-width', '10');

  svg
    .selectAll('polygon')
    .data([null])
    .join('polygon')
    .attr('points', '501,129 469,129 485,150')
    .attr('fill', 'orange');

  //creating the umbrella
  const arcGenerator = d3
    .arc()
    .outerRadius(125)
    .innerRadius(0)
    .startAngle(-Math.PI / 2)
    .endAngle(Math.PI / 2);

  const arc = svg
    .append('path')
    .attr('transform', 'translate(300,125)')
    .attr('d', arcGenerator())
    .attr('stroke', 'black')
    .attr('fill', '#FF0000');
  svg
    .selectAll('polygon2')
    .data([null])
    .join('polygon2')
    .attr('points', '501,129 469,129 485,150')
    .attr('fill', 'orange');
};
